@@ -11,7 +11,7 @@ from typing import List, Union, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from modelhub import ModelHub
-
+    from modelhub.series import SeriesLocationStack
 
 GroupByType = Union[List[Union[str, Series]], str, Series, NotSet]
 
@@ -123,6 +123,7 @@ class Aggregate:
 
             - if not_set it defaults to using :py:attr:`ModelHub.time_agg`.
             - if None it aggregates over all data.
+        :param exclude_bounces: if True only session durations greater than 0 will be considered
         :param method: 'mean' or 'sum'
         :returns: series with results.
         """
@@ -142,10 +143,10 @@ class Aggregate:
 
         gdata = self._check_groupby(data=data, groupby=new_groupby)
         session_duration = gdata.aggregate({'moment': ['min', 'max']})
-        session_duration['session_duration'] = session_duration['moment_max']-session_duration['moment_min']
+        session_duration['session_duration'] = session_duration['moment_max'] - session_duration['moment_min']
 
         if exclude_bounces:
-            session_duration = session_duration[(session_duration['session_duration'] > '0')]
+            session_duration = session_duration[(session_duration['session_duration'].dt.total_seconds > 0)]
 
         if method not in ['sum', 'mean']:
             raise ValueError("only 'sum and 'mean' are supported for `method`")
@@ -168,3 +169,94 @@ class Aggregate:
         frequency = total_sessions_user.groupby(['session_id_nunique']).aggregate({'user_id': 'nunique'})
 
         return frequency.user_id_nunique
+
+    def top_product_features(self,
+                             data: bach.DataFrame,
+                             location_stack: 'SeriesLocationStack' = None,
+                             event_type: str = 'InteractiveEvent') -> bach.DataFrame:
+        """
+        Calculate the top used features in the product.
+
+        :param data: :py:class:`bach.DataFrame` to apply the method on.
+        :param location_stack: the location stack
+
+            - can be any slice of a :py:class:`modelhub.SeriesLocationStack` type column
+            - if None - the whole location stack is taken.
+        :param event_type: event type. Must be a valid event_type (either parent or child).
+        :returns: bach DataFrame with results.
+        """
+
+        data = data.copy()
+
+        self._mh._check_data_is_objectiv_data(data)
+
+        # the following columns have to be in the data
+        data['_application'] = data.global_contexts.gc.application
+
+        if location_stack is not None:
+            data['_feature_nice_name'] = location_stack.ls.nice_name
+        else:
+            data['_feature_nice_name'] = data.location_stack.ls.nice_name
+
+        groupby_col = ['_application', '_feature_nice_name', 'event_type']
+
+        # selects specific event types, so stack_event_types must be a superset of [event_types]
+        interactive_events = data[data.stack_event_types >= [event_type]]
+
+        # users by feature
+        users_feature = interactive_events.groupby(groupby_col).agg({'user_id': 'nunique'})
+        return users_feature.sort_values('user_id_nunique', ascending=False)
+
+    def top_product_features_before_conversion(self,
+                                               data: bach.DataFrame,
+                                               name: str,
+                                               location_stack: 'SeriesLocationStack' = None,
+                                               event_type: str = 'InteractiveEvent') -> bach.DataFrame:
+        """
+        Calculates what users did before converting by
+        combining several models from the model hub.
+
+        :param data: :py:class:`bach.DataFrame` to apply the method on.
+        :param name: label of the conversion event.
+        :param location_stack: the location stack
+
+            - can be any slice of a :py:class:`modelhub.SeriesLocationStack` type column
+            - if None - the whole location stack is taken.
+        :param event_type: event type. Must be a valid event_type
+            (either parent or child).
+        :returns: bach DataFrame with results.
+        """
+
+        data = data.copy()
+        self._mh._check_data_is_objectiv_data(data)
+
+        if not name:
+            raise ValueError('Conversion event label is not provided.')
+
+        data['_application'] = data.global_contexts.gc.application
+
+        if location_stack is not None:
+            data['_feature_nice_name'] = location_stack.ls.nice_name
+        else:
+            data['_feature_nice_name'] = data.location_stack.ls.nice_name
+
+        # label sessions with a conversion
+        data['converted_users'] = self._mh.map.conversions_counter(data,
+                                                                   name=name) >= 1
+
+        # label hits where at that point in time, there are 0 conversions in the session
+        data['zero_conversions_at_moment'] = self._mh.map.conversions_in_time(data,
+                                                                              name) == 0
+
+        # filter on above created labels
+        converted_users = data[(data.converted_users & data.zero_conversions_at_moment)]
+
+        # select only user interactions
+        converted_users_filtered = converted_users[converted_users.stack_event_types >= [event_type]]
+
+        converted_users_features = self._mh.agg.unique_users(converted_users_filtered,
+                                                             groupby=['_application',
+                                                                      '_feature_nice_name',
+                                                                      'event_type'])
+
+        return converted_users_features.sort_values(ascending=False).to_frame()
