@@ -58,31 +58,31 @@ class Map:
         """
 
         self._mh._check_data_is_objectiv_data(data)
+        frame_args = {
+            'mode': WindowFrameMode.ROWS,
+            'start_boundary': WindowFrameBoundary.PRECEDING,
+            'end_boundary': WindowFrameBoundary.FOLLOWING,
+        }
+        data_cp = data[['session_id', 'user_id']]
+        data_cp['time_agg'] = self._mh.time_agg(data, time_aggregation)
 
-        window = data.groupby('user_id').window(
-            mode=WindowFrameMode.ROWS,
-            start_boundary=WindowFrameBoundary.PRECEDING,
-            start_value=None,
-            end_boundary=WindowFrameBoundary.FOLLOWING,
-            end_value=None)
+        window = data_cp.groupby('user_id').window(**frame_args)
+        window_ta = data_cp.groupby(['time_agg', 'user_id']).window(**frame_args)
 
-        is_first_session = window['session_id'].min()
+        # for BigQuery, window.base_node != ta_window.base_node
+        # as bach.DataFrame.groupby materializes for this engine
+        # therefore time_agg will be referenced as a column in window expression
+        # materialization is needed since time_agg is not a column in  current data_cp.base_node
+        if window.base_node != window_ta.base_node:
+            data_cp = data_cp.materialize(node_name='time_agg_window')
 
-        window = data.groupby([self._mh.time_agg(data, time_aggregation),
-                               'user_id']).window(
-            mode=WindowFrameMode.ROWS,
-            start_boundary=WindowFrameBoundary.PRECEDING,
-            start_value=None,
-            end_boundary=WindowFrameBoundary.FOLLOWING,
-            end_value=None)
-        is_first_session_time_aggregation = window['session_id'].min()
+        session_id_series = data_cp['session_id']
+        is_first_session = session_id_series.min(partition=window)
+        is_first_session_time_aggregation = session_id_series.min(partition=window_ta)
 
-        series = is_first_session_time_aggregation == is_first_session
-
-        new_series = series.copy_override(name='is_new_user',
-                                          index=data.index).materialize()
-
-        return new_series
+        is_new_user_series = is_first_session_time_aggregation == is_first_session
+        is_new_user_series = is_new_user_series.copy_override_type(bach.SeriesBoolean)
+        return is_new_user_series.copy_override(name='is_new_user').materialize()
 
     def is_conversion_event(self, data: bach.DataFrame, name: str) -> bach.SeriesBoolean:
         """
@@ -96,14 +96,17 @@ class Map:
 
         self._mh._check_data_is_objectiv_data(data)
 
+        if name not in self._mh._conversion_events:
+            raise KeyError(f"Key {name} is not labeled as a conversion")
+
         conversion_stack, conversion_event = self._mh._conversion_events[name]
 
         if conversion_stack is None:
             series = data.event_type == conversion_event
         elif conversion_event is None:
-            series = conversion_stack.notnull()
+            series = conversion_stack.json.get_array_length() > 0
         else:
-            series = ((conversion_stack.notnull()) & (data.event_type == conversion_event))
+            series = ((conversion_stack.json.get_array_length() > 0) & (data.event_type == conversion_event))
         return series.copy_override(name='is_conversion_event')
 
     def conversions_counter(self,
