@@ -1,17 +1,17 @@
 """
 Copyright 2021 Objectiv B.V.
 """
-
-# Any import from modelhub initializes all the types, do not remove
-from modelhub import __version__
-from tests_modelhub.functional.modelhub.data_and_utils import get_bt_with_json_data_real
+import pytest
+from modelhub import __version__  # Any import from modelhub initializes all the types, do not remove
+from tests_modelhub.data_and_utils.utils import get_df_with_json_data_real, DBParams
 from tests.functional.bach.test_data_and_utils import assert_equals_data
 
 
-def test_get_real_data():
-    bt = get_bt_with_json_data_real()
+def test_get_real_data(db_params: DBParams):
+    bt = get_df_with_json_data_real(db_params)
     assert_equals_data(
         bt,
+        use_to_pandas=True,
         expected_columns=['_index_event_id', 'event_id', 'global_contexts', 'location_stack'],
         expected_data=[
             [1, 1, [{'id': 'rod-web-demo', '_type': 'ApplicationContext'}, {'id': 'http_context', '_type': 'HttpContext', 'referrer': 'https://rick.objectiv.io/', 'user_agent': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:94.0) Gecko/20100101 Firefox/94.0', 'remote_address': '144.144.144.144'}, {'id': 'f84446c6-eb76-4458-8ef4-93ade596fd5b', '_type': 'CookieIdContext', 'cookie_id': 'f84446c6-eb76-4458-8ef4-93ade596fd5b'}], [{'id': '#document', 'url': 'https://rick.objectiv.io/', '_type': 'WebDocumentContext'}, {'id': 'home', '_type': 'SectionContext'}, {'id': 'yep', '_type': 'SectionContext'}, {'id': 'cc91EfoBh8A', '_type': 'SectionContext'}]],
@@ -23,8 +23,8 @@ def test_get_real_data():
     )
 
 
-def test_objectiv_stack_type():
-    bt = get_bt_with_json_data_real()
+def test_objectiv_stack_type(db_params):
+    bt = get_df_with_json_data_real(db_params)
 
     bt['a'] = bt.global_contexts.astype('objectiv_global_context')
     bts = bt.a.objectiv.get_from_context_with_type_series("CookieIdContext", "cookie_id")
@@ -41,8 +41,8 @@ def test_objectiv_stack_type():
     )
 
 
-def test_objectiv_stack_type2():
-    bt = get_bt_with_json_data_real()
+def test_objectiv_stack_type2(db_params):
+    bt = get_df_with_json_data_real(db_params)
 
     bt['a'] = bt.global_contexts.astype('objectiv_global_context')
     bts = bt.a.global_contexts.user_agent
@@ -59,8 +59,9 @@ def test_objectiv_stack_type2():
     )
 
 
-def test_objectiv_stack_type3():
-    bt = get_bt_with_json_data_real()
+@pytest.mark.skip_bigquery  # TODO: BigQuery
+def test_objectiv_stack_type3(db_params):
+    bt = get_df_with_json_data_real(db_params)
 
     bt['b'] = bt.location_stack.astype('objectiv_location_stack')
     bts = bt.b.location_stack.navigation_features
@@ -68,17 +69,18 @@ def test_objectiv_stack_type3():
         bts,
         expected_columns=['_index_event_id', 'b'],
         expected_data=[
-            [1, None],
+            [1, []],
             [2, [{'id': 'navigation', '_type': 'NavigationContext', '_types': ['AbstractContext', 'AbstractLocationContext', 'NavigationContext', 'SectionContext']}]],
-            [3, None],
-            [4, None],
-            [5, None]
+            [3, []],
+            [4, []],
+            [5, []]
         ]
     )
 
 
-def test_objectiv_stack_type4():
-    bt = get_bt_with_json_data_real()
+@pytest.mark.skip_bigquery  # TODO: BigQuery
+def test_objectiv_stack_type4(db_params):
+    bt = get_df_with_json_data_real(db_params)
 
     bt['b'] = bt.location_stack.astype('objectiv_location_stack')
     bts = bt.b.location_stack.feature_stack
@@ -96,8 +98,9 @@ def test_objectiv_stack_type4():
     )
 
 
-def test_objectiv_stack_type5():
-    bt = get_bt_with_json_data_real()
+@pytest.mark.skip_bigquery  # TODO: BigQuery
+def test_objectiv_stack_type5(db_params):
+    bt = get_df_with_json_data_real(db_params)
 
     bt['b'] = bt.location_stack.astype('objectiv_location_stack')
     bts = bt.b.location_stack.nice_name
